/**
 *
 */
package edu.agh.sm2006.nmea2kml;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @author Kuba Madej
 *
 */
public class Location {

	private static final String FIELD_SEPARATOR = ",";

	private static final int LATITUDE_COORDS_INDEX = 3;

	private static final int LATITUDE_HEMISPHERE_INDEX = 4;

	private static final String SOUTHERN_HEMISPHERE = "S";

	private static final int LONGTITUDE_HEMISPHERE_INDEX = 6;

	private static final Object WESTERN_HEMISPHERE = "W";

	private static final int LONGTITUDE_COORDS_INDEX = 5;

	private static final int SPEED_INDEX = 7;

	private static final int DATE_INDEX = 9;

	private static final int TIME_INDEX = 1;

	private double latitude;

	private double longtitude;

	private Date time;

	private double speed;

	public Location(String _data) throws ParseException {
		final String[] data = _data.split(FIELD_SEPARATOR);

		double latitude = Double.parseDouble(data[LATITUDE_COORDS_INDEX]);
		this.latitude = ((int) latitude) / 100;
		this.latitude += (latitude % 100) / 60;
		if (data[LATITUDE_HEMISPHERE_INDEX].equals(SOUTHERN_HEMISPHERE))
			this.latitude *= -1;

		double longtitude = Double.parseDouble(data[LONGTITUDE_COORDS_INDEX]);
		this.longtitude = ((int) longtitude) / 100;
		this.longtitude += (longtitude % 100) / 60;
		if (data[LONGTITUDE_HEMISPHERE_INDEX].equals(WESTERN_HEMISPHERE))
			this.longtitude *= -1;

		final String dateTime = data[DATE_INDEX] + data[TIME_INDEX];
		try {
			time = new SimpleDateFormat("ddMMyyHHmmss.SSS").parse(dateTime);
		} catch (ParseException ex) {
			time = new SimpleDateFormat("ddMMyyHHmmss").parse(dateTime);
		}

		speed = Double.parseDouble(data[SPEED_INDEX]);
	}

	public double getLatitude() {
		return latitude;
	}

	public double getLongtitude() {
		return longtitude;
	}

	public double getSpeed() {
		return speed;
	}

	public Date getTime() {
		return time;
	}
}
